<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;

class EmailQueue extends Model {

    public $table = 'mail_queue';
    public $primaryKey = 'id';

    protected $fillable = [
        'label',
        'type',
        'status',
        'info',
        'mail_json',
        'to',
        'from',
        'cc',
        'ccn',
        'send_at'
    ];

}
